"""
nopo
~~~~

nopo (not only page object) is a package for Page Object Model (POM),
a tool based on Selenium that helps you build POM in web test.

Full documentation is in README.md.

:copyright: (c) 2021 by Ding Junyao.
:license: Apache 2.0, see LICENSE for more details.
"""

from .el import El
from .els import Els
from .by import By
from .pg import Pg
